Plot a donut chart of observations contributing to eLTER Standard Observations
Source:R/charts.R
obs_SO_pie_chart.RdProduces a donut chart showing the number of observations contributing to eLTER Standard Observations SOBIO_014 (Flying insects) and SOBIO_018 (Acoustic recording). Observations can contribute to both SOs simultaneously (e.g. Orthoptera).
Value
A ggplot object printed to the active device.
Author
Alessandro Oggioni, PhD alessandro.oggioni@cnr.it