Skip to contents

[Experimental]

Takes a tibble of iNaturalist occurrences and produces a stacked bar chart of observations per year, coloured by iconic taxon group. All years from the first observation to the current year are shown, including years with zero observations.

Usage

obs_per_year(df)

Arguments

df

An sf tibble of iNaturalist occurrences containing at least the columns observed_on_details.year and taxon.iconic_taxon_name.

Value

A ggplot object printed to the active device.

Author

Alessandro Oggioni, PhD alessandro.oggioni@cnr.it

Alice Lenzi, phD alice.lenzi@crea.gov.it

Examples

if (FALSE) { # \dontrun{
obs_per_year(occ_eLTER_legal)
} # }