R/data.R
site_boundary.Rd
An sf object representing the boundary of the Montagna di Torricchio eLTER site retrieved via ReLTER::get_site_info().
sf
ReLTER::get_site_info()
site_boundary
An sf object with site metadata and boundary polygon.
https://deims.org/6b62feb2-61bf-47e1-b97f-0e909c408db8