Skip to contents

[Experimental]

Takes a tibble of iNaturalist occurrences and produces a grouped bar chart showing the total number of observations and unique species for each iconic taxonomic group as defined by iNaturalist.

Usage

iconic_taxa(df)

Arguments

df

An sf tibble of iNaturalist occurrences containing at least the columns taxon.iconic_taxon_name and name.

Value

A ggplot object printed to the active device.

Author

Alessandro Oggioni, PhD alessandro.oggioni@cnr.it

Alice Lenzi, phD alice.lenzi@crea.gov.it

Examples

if (FALSE) { # \dontrun{
iconic_taxa(occ_eLTER_legal)
} # }