![[Experimental]](figures/lifecycle-experimental.svg)
Takes a tibble of iNaturalist occurrences and produces a horizontal bar
chart of the top n most observed species, coloured by iconic taxon
group. If fewer than n species have more than one observation, all
species are shown.
Usage
top_n_species(df, n = 10)
Arguments
- df
An sf tibble of iNaturalist occurrences containing at least
the columns name and taxon.iconic_taxon_name.
- n
Integer. Number of top species to display. Default is 10.
Value
A ggplot object printed to the active device.
Examples
if (FALSE) { # \dontrun{
top_n_species(occ_eLTER_legal)
top_n_species(occ_eLTER_legal, n = 20)
} # }